import React, {useState} from 'react';
import Lottie from 'lottie-react-native';
import Home from './src/components/Home';
import Login from './src/components/Login';
import Signup from './src/components/Signup';
import Cart from './src/components/Cart';
import Icon from 'react-native-vector-icons/FontAwesome';
import ProductDetail from './src/components/ProductDetail';
import MedicineList from './src/components/MedicineList';
import {NavigationContainer} from '@react-navigation/native';
import {createNativeStackNavigator} from '@react-navigation/native-stack';
import CartProvider from './src/store/CartContext';
import {Colors} from './src/constants/Constants';

const Stack = createNativeStackNavigator();

function App() {
  const [isLoading, setLoading] = useState(true);

  setTimeout(() => {
    setLoading(false);
  }, 6000);

  if (isLoading) {
    return (
      <Lottie
        source={require('./src/assets/splash_screen.json')}
        autoPlay
        loop
      />
    );
  }
  return (
    <CartProvider>
      <NavigationContainer>
        <Stack.Navigator>
          <Stack.Screen name="Home" component={Home} options={{title: ''}} />
          <Stack.Screen name="Signup" component={Signup} />
          <Stack.Screen name="Login" component={Login} />
          <Stack.Screen
            name="MedicineList"
            component={MedicineList}
            options={{
              title: 'Product List',
              headerRight: () => (
                <Icon
                  name="shopping-cart"
                  size={30}
                  color={Colors.primary500}></Icon>
              ),
            }}
          />
          <Stack.Screen
            name="ProductDetail"
            component={ProductDetail}
            options={{
              title: 'Product Detail',
              headerRight: () => (
                <Icon
                  name="shopping-cart"
                  size={30}
                  color={Colors.primary500}></Icon>
              ),
            }}
          />
          <Stack.Screen name="Cart" component={Cart} />
        </Stack.Navigator>
      </NavigationContainer>
    </CartProvider>
  );
}

export default App;
