import React, {useContext, useState} from 'react';
import {View, Text, StyleSheet, Button, Image} from 'react-native';
import {CartContext} from '../store/CartContext';

const CartItem = ({item}) => {
  const {removeFromCart, updateQuantity} = useContext(CartContext);

  const handleRemoveFromCart = () => {
    removeFromCart(item.product);
  };

  const handleUpdateQuantity = newQuantity => {
    updateQuantity(item.product, newQuantity);
  };

  // setTotal(total + (item.product.price * item.quantity));

  return (
    <View style={styles.itemContainer}>
      <View style={styles.imageContainer}>
        <Image source={item.product.image} style={styles.image} />
      </View>
      <View style={styles.detailContainer}>
        <Text>{item.product.name}</Text>
        <Text style={styles.price}>{item.product.price}</Text>
      </View>
      <View style={styles.qtyContainer}>
        <Button title="-" onPress={handleRemoveFromCart} />
        <Button
          title="-"
          onPress={() => handleUpdateQuantity(item.quantity - 1)}
        />
        <Text>{item.product.quantity}</Text>
        <Button
          title="+"
          onPress={() => handleUpdateQuantity(item.quantity + 1)}
        />
      </View>
    </View>
  );
};

const Cart = () => {
  const {cart} = useContext(CartContext);
  const [total, setTotal] = useState(0);

  return (
    <View style={styles.cartContiner}>
      {cart.map(item => (
        <CartItem key={item.product.id} item={item} />
      ))}
      <Text style={styles.title}>Total</Text>
    </View>
  );
};

const styles = StyleSheet.create({
  cartContiner: {
    flex: 1,
  },
  itemContainer: {
    flex: 0.5,
    padding: 10,
    flexDirection: 'row',
    justifyContent: 'flex-start',
    height: '10%',
  },
  imageContainer: {
    flex: 1,
    backgroundColor: 'blue',
  },
  detailContainer: {
    flex: 3,
    backgroundColor: '#ccc',
  },
  title: {
    fontSize: 20,
    fontWeight: 'bold',
    marginBottom: 10,
  },
  qtyContainer: {
    flex: 2,
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'center',
    marginBottom: 10,
    borderBottomWidth: 1,
    borderBottomColor: '#ccc',
    paddingBottom: 5,
  },
  name: {
    fontSize: 16,
    fontWeight: 'bold',
  },
  quantity: {
    fontSize: 14,
    color: '#888',
  },
  image: {
    width: 80,
    height: 80,
  },
  price: {
    fontSize: 14,
    color: '#888',
  },
});

export default Cart;
